pub struct PreferredRule {
pub preferred: u32,
}Expand description
The acceptability that marks a designation as preferred in a language
reference set, as the code system spells it (for SNOMED, the SCTID of
|Preferred|).
Fields
preferred: u32The acceptability ordinal meaning preferred.